import { BaseVisitor, ParsedConfig, RawConfig } from './base-visitor';
import { EnumValuesMap, ScalarsMap } from './types';
import { OperationVariablesToObject } from './variables-to-object';
import { DeclarationBlockConfig } from './utils';
import { InputObjectTypeDefinitionNode, InputValueDefinitionNode, NameNode, FieldDefinitionNode, ObjectTypeDefinitionNode, EnumTypeDefinitionNode, DirectiveDefinitionNode, ListTypeNode, GraphQLSchema, NonNullTypeNode, UnionTypeDefinitionNode, InterfaceTypeDefinitionNode, ScalarTypeDefinitionNode, EnumValueDefinitionNode, NamedTypeNode } from 'graphql';
export interface ParsedTypesConfig extends ParsedConfig {
    enumValues: EnumValuesMap;
}
export interface RawTypesConfig extends RawConfig {
    enumValues?: EnumValuesMap;
}
export declare class BaseTypesVisitor<TRawConfig extends RawTypesConfig = RawTypesConfig, TPluginConfig extends ParsedTypesConfig = ParsedTypesConfig> extends BaseVisitor<TRawConfig, TPluginConfig> {
    protected _schema: GraphQLSchema;
    protected _argumentsTransformer: OperationVariablesToObject;
    constructor(_schema: GraphQLSchema, rawConfig: TRawConfig, additionalConfig: TPluginConfig, defaultScalars?: ScalarsMap);
    readonly scalarsDefinition: string;
    setDeclarationBlockConfig(config: DeclarationBlockConfig): void;
    setArgumentsTransformer(argumentsTransfomer: OperationVariablesToObject): void;
    NonNullType(node: NonNullTypeNode): string;
    InputObjectTypeDefinition(node: InputObjectTypeDefinitionNode): string;
    InputValueDefinition(node: InputValueDefinitionNode): string;
    Name(node: NameNode): string;
    FieldDefinition(node: FieldDefinitionNode): string;
    UnionTypeDefinition(node: UnionTypeDefinitionNode, key: string | number, parent: any): string;
    ObjectTypeDefinition(node: ObjectTypeDefinitionNode, key: number | string, parent: any): string;
    InterfaceTypeDefinition(node: InterfaceTypeDefinitionNode): string;
    ScalarTypeDefinition(node: ScalarTypeDefinitionNode): string;
    EnumTypeDefinition(node: EnumTypeDefinitionNode): string;
    protected buildEnumValuesBlock(values: ReadonlyArray<EnumValueDefinitionNode>): string;
    DirectiveDefinition(node: DirectiveDefinitionNode): string;
    protected _getScalar(name: string): string;
    protected _getTypeForNode(node: NamedTypeNode): string;
    NamedType(node: NamedTypeNode): string;
    ListType(node: ListTypeNode): string;
    SchemaDefinition(): any;
    protected wrapWithListType(str: string): string;
}
