import { SelectionSetNode, FieldNode, FragmentSpreadNode, InlineFragmentNode, GraphQLNamedType, GraphQLSchema } from 'graphql';
import { ScalarsMap, ConvertNameFn } from './types';
import { GraphQLObjectType, GraphQLNonNull, GraphQLList } from 'graphql';
import { BaseVisitorConvertOptions } from './base-visitor';
export declare type PrimitiveField = string;
export declare type PrimitiveAliasedFields = {
    alias: string;
    fieldName: string;
};
export declare type LinkField = {
    alias: string;
    name: string;
    type: string;
    selectionSet: string;
};
export declare type FragmentSpreadField = string;
export declare type InlineFragmentField = {
    [onType: string]: string[];
};
export declare class SelectionSetToObject {
    protected _scalars: ScalarsMap;
    protected _schema: GraphQLSchema;
    protected _convertName: ConvertNameFn<BaseVisitorConvertOptions>;
    protected _addTypename: boolean;
    protected _parentSchemaType?: GraphQLNamedType;
    protected _selectionSet?: SelectionSetNode;
    protected _primitiveFields: PrimitiveField[];
    protected _primitiveAliasedFields: PrimitiveAliasedFields[];
    protected _linksFields: LinkField[];
    protected _fragmentSpreads: FragmentSpreadField[];
    protected _inlineFragments: InlineFragmentField;
    protected _queriedForTypename: boolean;
    constructor(_scalars: ScalarsMap, _schema: GraphQLSchema, _convertName: ConvertNameFn<BaseVisitorConvertOptions>, _addTypename: boolean, _parentSchemaType?: GraphQLNamedType, _selectionSet?: SelectionSetNode);
    createNext(parentSchemaType: GraphQLNamedType, selectionSet: SelectionSetNode): SelectionSetToObject;
    protected wrapTypeWithModifiers(baseType: string, type: GraphQLObjectType | GraphQLNonNull<GraphQLObjectType> | GraphQLList<GraphQLObjectType>): string;
    _collectField(field: FieldNode): void;
    _collectFragmentSpread(node: FragmentSpreadNode): void;
    _collectInlineFragment(node: InlineFragmentNode): void;
    readonly string: string;
    protected mergeAllFields(fieldsSet: Array<string | null>): string;
    protected buildTypeNameField(): string | null;
    protected buildPrimitiveFields(parentName: string, fields: PrimitiveField[]): string | null;
    protected buildAliasedPrimitiveFields(parentName: string, fields: PrimitiveAliasedFields[]): string | null;
    protected formatNamedField(name: string): string;
    protected buildLinkFields(fields: LinkField[]): string | null;
    protected buildInlineFragments(inlineFragments: InlineFragmentField): string | null;
    protected buildFragmentSpread(fragmentsSpread: FragmentSpreadField[]): string | null;
}
